"""Constants."""
from __future__ import annotations

from typing import Final

USER_POOL_ID: Final = "dXMtZWFzdC0xX0xhQjcxOGhZdg=="
CLIENT_ID: Final = "NGlla3ViYXQwamI1aWxqZmJhYWxzaXFmOWo="

FRAGRANCES: Final[dict[str, str]] = {
    "AJV": "Birchwood Pine",
    "AWF": "Winter Frost",
    "BAS": "Sally Black Amber Spice",
    "BMC": "Balsam & Cedar",
    "CCA": "Cocoa Almond",
    "CRS": "Prosecco",
    "DEM": "Del Mar",
    "DZI": "Orange Blossom",
    "EGR": "Evergreen",
    "FIG": "Fig Tree",
    "GNG": "Gingerbread",
    "HST": "Ski Trip",
    "HWM": "Winter Mantel",
    "JPK": "Jack the Pumpkin King",
    "JRG": "Elsa Journeys to Ahtohallan",
    "JVB": "Vanilla Chiffon",
    "JZB": "Velvet Wineberry",
    "JZJ": "Egyptian Sandalwood",
    "KCZ": "Santorini",
    "KDR": "Ocean Mist & Sea Salt",
    "KDM": "Crystal Pine",
    "KYV": "Tuscan Neroli",
    "LHT": "Anna & Olaf in the Enchanted Forest",
    "LMS": "Sunday Morning",
    "LPO": "Love Potion",
    "LWZ": "Sweet Grace",
    "MBZ": "Pumpkin Chai",
    "MGL": "13-Relaxation",
    "NDM": "Volcano",
    "PJT": "Amalfi Lemon & Mint",
    "QPH": "Honey Mint",
    "RME": "Rosemary Eucalyptus",
    "SLQ": "Perfume Immortelle",
    "TWL": "Blue Water Lotus",
    "UDZ": "Bamboo",
    "VNT": "Holiday",
    "VQS": "Rose & Wild Blackberry",
    "VXE": "White Vetiver",
    "WRT": "Charcoal",
    "WTN": "Winter Noir",
    "XLJ": "Peony & Silk",
    "XKA": "Green Tea Citrus",
}
